package Bundle::ePortal;

$VERSION = 0.08;

1;

__END__

=head1 NAME

Bundle::ePortal - Bundle with all ePortal related modules




=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::ePortal'>





=head1 CONTENTS

Apache::Request

CGI

Data::Dumper

Date::Calc

DBD::mysql

DBI

Digest::MD5

Error

HTML::Mason

Image::Size

List::Util

Mail::Sendmail

MIME::Base64

Net::LDAP

Params::Validate

Storable

Text::Wrap

Unicode::Map8

Unicode::String

URI

ePortal::Server


=head1 DESCRIPTION

This bundle contains all modules related to the ePortal project.
See http://eportal.sourceforge.net/ for details about it.







=head1 AUTHOR

Sergey Rusakov, E<lt>rusakov_sa@users.sourceforge.netE<gt>






=head1 SEE ALSO

http://eportal.sourceforge.net/

=cut
